/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvSignalEnvelope.h"
#include "HvControlCast.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_UVBPyGxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_euJTJVVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dDR7cGbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g9R6fbBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_imyoW4DL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PPqZWOkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wotaj0sA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v3rbAjwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EhP55das_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DsnAWKfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MPZvBgy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pnvv56Hn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BRLqlJoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RCnhPT70_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rTp0L0WR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IvXZvdQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zEMvhRCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vRCLCpJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qH9uqMoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kfSdvrn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3yOQT6Lm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2a29g6EB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_VeAslTpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S4mAubXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9mYDL8zN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gMeglFbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hy9Rv6eU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ay74qSvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bkEyuYt9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_a4vaPRBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7zNMPa90_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AovBBFA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EyW3kH6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_73A49K4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LHV0btf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oe9fWCYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4BoFCNCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wyWNhpOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GV1L14ga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gmyu3H1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xI3ZGmLB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cWxIsQvu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8PWnojB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MeOnCuNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CttjiQBN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_i4lJlum2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AGEnDE1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TbeAEtDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b9hAcDI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7jH9sZmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TQLNF5NL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nMz6Pepx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fu5oWcjB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E0Yn0dgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lvg64PZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_idci1RXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_a7kAEyJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ndkOAzzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_It2xytWu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lA3ZnZ0v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XbwRhOik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oGf50rW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jw6q25MC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2nPIUMvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4M64ZniY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jOwfSNdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tmoUb8U8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8WCVt6jZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zce3J0KU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HwHUgsum_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XAUFnb4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dzlAE4oI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BVEHbvI2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_czpKD3qZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CqttxXwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qfDumyIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7fDftAF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mS84Lclo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pq4F3zSB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_URP6P3gj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U8w15t9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0jV1V5ki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IzSBbW5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IKhwzjkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_g9XSgTUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6TGav5UX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dMLjhOmN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tQHuqa0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NzDhoKFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ulj5Hy18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VxJwDQrP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iylZ0nOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ghLxTB4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sWHfBk3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AicimXri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JuMk3s25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ctRGjDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t4DGmfmW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XLgle3Om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cQcMrbIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZtB3AOlw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Nec9xF3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wFlUlTVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I9ngjZWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_THqmVpsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R6ekfP52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NPIeF8o6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3DhQdAlj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g2uZhkW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wchuX93u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UYwMXMWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xEgycUIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_H6xLdGzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DfqhRHqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_adtPpo7E_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vtrKIoPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k7olnrlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MR7W3ywe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7fpAP2UT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qGumFeV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CHPxug00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RyxhkfIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hh6WqnQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OmPwJd6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SHjkXhLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gUT0VI35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Qx8vcvSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9wuL8x1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PFEto2iQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_rLDnaLFb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_psTHmoHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_URKIcWhu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dDJp6iBV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p0bLuwlg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ec4zcPa7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fpnroa75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vtcRoG1N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UiJ9sQiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6QxLAOkj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AFofeXFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wc5hJjmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o2Dlx29k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ddz8W2Rj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_j1JMZz9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBtjmar7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1Ygf4LYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oOoGsf4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qeVRj3Lg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QjjTGYJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ghFF6k3b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kskLo51O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AXa4ovv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K5UXoDvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rFjI23eE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YmtYJTvE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rZAz8nHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rO69k2H2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_F6Ei4VFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wXc6EqxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Rne9swN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lEFCJ859_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q9LPaTRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BqT38R4B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gjfEajOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_82qdlfKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ftKZkAtL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L8DBYL8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDA9ENAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9osk8cHI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EBLgVK9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YxVG1h7Z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Mwctp88J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_faF1KyWG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GEtpIipS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xpF2UHJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_knFXUE3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tlJkcFem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cwl3pYSU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2jo6f0OV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CD8hCFZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bQQoA8ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OC9kbWvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o3M58gPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vGcRtKTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2qFlc0GD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_I4IjzRNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fJdLTN7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OUSPFOBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GUUoqMhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AB77MZSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n8mVFAD1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xHfoeKgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bLJdsvGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_po8An6mt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_abliledI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5EShUZFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eAIXhpYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ydz2rSPK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THME8nTR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FSEfB4kZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gp7vSUNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ogfDQKOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BSW8WaOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xQXIsK42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XXE02jYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZOn9Ybzb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w8FjVf5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WQ8e7QfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yTzmTflb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SuR0cBTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WeMopQq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UmrhPkaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zTUGXTrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aJSDTzpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Y18ZYQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_irzsAnxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wh1VF8aw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yqcxhaOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sDhe9BbX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0NkABrV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_66cf7POo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qw6ABwe0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9iphVohR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eSpQ4dbR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XC1fJ2Kf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ceJ3LGcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o5PjqcnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7e1TXQj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T199aLgo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0gmKwJiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R1sMVyCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S7pRVIh2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_liFm2D8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I0YIDAZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3K2QFzgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ct3qqmK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AnRLaulc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OBZyK9D1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a80Z1ZMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b7diI1vu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pJsJUQWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Rb5btp3X_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_orAAFeCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bzQWDuoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_703amVLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UpyXTIjK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_P66KE50H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BCxrgBxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mlONwrGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1996gANF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qyBPeETb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RThUq8Nk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9r25a2N7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aqU92NyX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zFcZkeTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BQmecZmK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vmXhZreK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KZg6MkXc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pDshuNln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RDU0FLiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_p5GlXw2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1rffhhhK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_KXAM6s9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rk4xMqC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sF3dkKRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pi8E5Bgg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8f92kS05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZId36CfC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_XDUJyCnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_5p9xpoVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hQjB7UPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x7asQgCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qlRITYVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XGqQNHEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TtmIGflA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F3UBBQ47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FpW3GSS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vM2F88qk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JDpYReFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y8b87xS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MHQnmeo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gNHtpeV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ajGAm4Js_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HKaraOV4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DiyRY5gi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ziqLsgJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_goYX5nTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9tprvi5t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZnM6pi2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aRtG8Dl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ans4wfFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3O7DtM8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JZqxHGrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N1l1Vvcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2HO8rlG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yu7omDfM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NP0b7JEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tWozNNvv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_htFxCeXQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cIZo57ZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Tm2HeCcD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_uMjdHhfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PJLI8LSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BaL7l1PA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vgRbj0LX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gk6GDTeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HwufovAs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_M7pdjBOC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NX5gTyUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xl3TyaSa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vNI67JXf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0kcd7wcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rxiCPymf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qoubq9Gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j2CHsiau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ki5jmLkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OC5c4Yw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SNZNegu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HlJmeLXb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A4tL90yi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YsSXUvfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mfOMYCSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JofborWP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_siO4NGB4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_EjGFuEqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AS7y6z7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZFoTbLrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iTLGUnDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e9dAzPPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LHMNQbOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n2NepWli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f6So2TNb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p3wKuE3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w3wCwise_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V3vYodht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EtRSOPMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gRS9em8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_50gr4ljl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_eiTR0K1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tyxm0jZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ChNyqvxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iwEkfBZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kNzB0FNt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T2g0lOgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AkJlzyOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AQhf57oZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K4c9WLEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P7Kn0tBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CpKiYGgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Fb84tml7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tZIveW8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_r4GpJXSt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_fbhBQuS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tGoa7wD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4kUV3JMe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aXzuuscj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ijAK8Iv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mo0ZxW81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XU1fxqqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n9OICG9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1L0SGwXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2RlmBrn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XljweFOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wrmj3ONQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SkpJZBCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ieeE1Ouz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_W5kFUxjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j83kAELU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vEFkmvgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KC39lpMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Uffnn3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E0inN2o1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fk88EZY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AfgG88Ji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1BKspfTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DSBbVXts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E8hMpCGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WDGBHqdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kO22RuFm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_V4oej15s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_9qJXbjXT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SQekpepI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_otVoNj4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fqq4gP8I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CyJajx3Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IDXotq9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_foCt7OdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JzsDKSNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dmljptMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3QcFN0vE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4VCE0yfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SN2p3rAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rnP4gXAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_f1uyLHPp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_LMJjubpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b9pWZ8Q1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0gclJtCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dLuLYpJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YFrSb46i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plbXim5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MKEIwumx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ejwLzsqY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TuFjDSCc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_urYOnV8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GdhrrKmr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xaeGsnKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CrEqybDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Cz7cMyn7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ET3tzOis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4zavIzD0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SrAAOunf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FkG8KS3b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EtuSoTKW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1mv13FS2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EdrnjQnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vWaP1WYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HAffUcJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L32w6Qnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ej0KXCFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xAehWXcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jJDa0kuY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BEsfv7QY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_bpilYngv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lJYHOxT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_grHt6QOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PuA4MjCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5FOknQS9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_89RUTauR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X7Oo9MKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dze8Pou7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HHruoi8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1B8pYqIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NCMzmjU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zPeK60qU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Qo3wmeev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qCjPNuR4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JoG8HDXi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cqs1kVLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C4pAOKFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PYZgv7EF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PTkaIJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dwOx1UZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6ft2WaUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_refpI5A1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_etEpVKNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RQk2MCDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uTkqbkqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4YAgU2Lo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_F6gViEac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ob3WlqeY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_f16WWIjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LvPOlfc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R3kAqCs0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oCTDrowa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IUZELJUe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mrOLGa9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bs3z7ezj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5VhrPyQD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RVrXyjsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YHngERJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NtF7fceG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LWrNqdVe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tmZ1B9j5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_co6TwLTS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ruYDjrmD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TfAWPuFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qpAcA22C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FcoMn8tM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HRvlsfli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q95DnK8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jmY2SwEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rdamaP13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hw420WrR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FUWSIsr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I9zIrgaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bOVx7f94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jCvBmojD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vvvQcVbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cY1sLx9L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HwmRhup2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JIjpQhWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tAocfQms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EzqUAkac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AB179jT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yJhZ13fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0eWcNnYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O5UKIuJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KiXm9a3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yw6SMTFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U3PkDCBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cORzIvWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_la5qQjOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ftZBFJM7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RepAqeLk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rFRGIiIm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x13K95f0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VtSolnr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mxpH3SZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HUYBjFbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2MpflSSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_me5i6glI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yepsO9Rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5zai2JdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pr5vu9VN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7rvJui82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0MrFiyuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tIIhqc4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lI9YQqJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_STghPm4g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RduAg9b5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OXg1SPgy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y3GDxshh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xj3LrocV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yw2Bh0rA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NYPrzQMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bOnd5Lvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9qo5hpYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7psmSk20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQg50L5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ebLxwvmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7JJU3VNW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_nAW923HN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_36fuV4Om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8JWWpMBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Z1E92uHs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_E7XtQ40z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7tFZj2P0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yUnSsEQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oGnXqt6A_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_KfGzKUTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fK5qLVgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_S87hD237_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_J8EaFbN8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UMuwtWbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jTI13zg5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_T1WxeqEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nK2ViHQh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LuxUNe4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ypWNznak_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sVEyTBpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4cp6d2xQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Af4LvOvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O2zpsHH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EbUIlVNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cuYSi4L2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WeKyVdLY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ws6vrIoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_y0FrAwLx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_lx1xHzs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GXHWqtF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6wsuyeYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HHYiRvye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vS9j5SBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3iBP1X2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NBOoysTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6CGy2ryo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tFRcV3Db_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ktBLRAWf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XxFwVh8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cc67jJBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L4VPKOam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nNxkUB81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ugO1GvOa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_l2I7kbWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nJWH7MIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yClKC1Vq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UlAmMIHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uz2J8gpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZlfKcOcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GjhLvFTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Eb7ztOYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6XS2Q23L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k9R1ZGZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oFG8Xktz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y2Of9MJh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RsoGDh9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D85wjjog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_npRP6ez2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7cbMbEdq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ht7kIrJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CdWAYdsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4HC8ZGJO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3XLaRrcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EeJwixdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5tb4MAb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wcl3zw5p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g16S0ohF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rpWnEasn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9w7NNbBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZFkSvyvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Gn4VnYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n5IeEk2B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r9uYT2d7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F1P9phkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fUNexbCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uHsdGA6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Vl0u6dsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8LN2Q7Zd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kRO2Njba_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HAKUnE9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lqrEN6ys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rxwMRWKG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_digrYlp4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RMw8wVGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZGYlasyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jI8hNGWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WmcLpa1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0RAhRzT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nhAve4l7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UPOJ9q4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mDMgPr9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DxuiZN6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3mnP7EhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R1NMWyCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_7CYmPH9c;
  SignalLine sLine_M2mowKDl;
  SignalLine sLine_sJDeZ1Q2;
  SignalLine sLine_kq6ik9OS;
  SignalLine sLine_CNDCVGgq;
  SignalLine sLine_7bwdEL1e;
  SignalLine sLine_EUlYdPIc;
  SignalLine sLine_CDuDlFF0;
  SignalLine sLine_KDwaeqBR;
  SignalLine sLine_sJEMvvnq;
  SignalLine sLine_CMIZNGbb;
  SignalLine sLine_nQU5ytFk;
  SignalEnvelope sEnv_XDUJyCnX;
  SignalEnvelope sEnv_5p9xpoVC;
  SignalLine sLine_GfEjBxHa;
  SignalLine sLine_wzfMWryP;
  SignalLine sLine_uMU7KxTM;
  SignalLine sLine_7WpoyCPh;
  SignalLine sLine_DmIfd1F8;
  SignalLine sLine_BhKLHbmO;
  SignalLine sLine_3MBDth2m;
  SignalLine sLine_vD2bKnot;
  SignalLine sLine_QSlqOFyM;
  SignalLine sLine_eN3lT8Js;
  SignalLine sLine_QjvQ1T2b;
  SignalLine sLine_q6TdOjHJ;
  SignalLine sLine_ovr54S2d;
  SignalLine sLine_iyFFNs4D;
  SignalLine sLine_2bwywloT;
  SignalLine sLine_Rx6jOTAq;
  SignalLine sLine_ceF7bNRq;
  SignalLine sLine_3RVs3ls9;
  SignalEnvelope sEnv_y0FrAwLx;
  SignalEnvelope sEnv_lx1xHzs9;
  SignalLine sLine_mUR0Vm0R;
  SignalLine sLine_OS8UkrNa;
  SignalLine sLine_U7UvyZeY;
  SignalLine sLine_4F7gYPA3;
  SignalLine sLine_cMfjKoHD;
  SignalLine sLine_SHZPc12Y;
  SignalLine sLine_c38bwa69;
  SignalLine sLine_7fO3WMiW;
  ControlVar cVar_UVBPyGxL;
  ControlBinop cBinop_euJTJVVv;
  ControlBinop cBinop_dDR7cGbA;
  ControlBinop cBinop_g9R6fbBW;
  ControlBinop cBinop_imyoW4DL;
  ControlBinop cBinop_v3rbAjwu;
  ControlBinop cBinop_DsnAWKfI;
  ControlBinop cBinop_MPZvBgy3;
  ControlBinop cBinop_pnvv56Hn;
  ControlVar cVar_BRLqlJoi;
  ControlVar cVar_RCnhPT70;
  ControlVar cVar_rTp0L0WR;
  ControlVar cVar_IvXZvdQl;
  ControlVar cVar_zEMvhRCB;
  ControlBinop cBinop_vRCLCpJm;
  ControlVar cVar_kfSdvrn1;
  ControlVar cVar_3yOQT6Lm;
  ControlIf cIf_bkEyuYt9;
  ControlIf cIf_a4vaPRBB;
  ControlDelay cDelay_AovBBFA0;
  ControlBinop cBinop_LHV0btf3;
  ControlBinop cBinop_oe9fWCYW;
  ControlIf cIf_8PWnojB0;
  ControlIf cIf_MeOnCuNX;
  ControlDelay cDelay_i4lJlum2;
  ControlBinop cBinop_b9hAcDI5;
  ControlBinop cBinop_7jH9sZmR;
  ControlIf cIf_a7kAEyJG;
  ControlIf cIf_ndkOAzzN;
  ControlDelay cDelay_lA3ZnZ0v;
  ControlBinop cBinop_jw6q25MC;
  ControlBinop cBinop_2nPIUMvq;
  ControlIf cIf_XAUFnb4T;
  ControlIf cIf_dzlAE4oI;
  ControlDelay cDelay_czpKD3qZ;
  ControlBinop cBinop_7fDftAF5;
  ControlBinop cBinop_mS84Lclo;
  ControlIf cIf_g9XSgTUx;
  ControlIf cIf_6TGav5UX;
  ControlDelay cDelay_tQHuqa0U;
  ControlBinop cBinop_VxJwDQrP;
  ControlBinop cBinop_iylZ0nOq;
  ControlIf cIf_XLgle3Om;
  ControlIf cIf_cQcMrbIK;
  ControlDelay cDelay_Nec9xF3e;
  ControlBinop cBinop_THqmVpsr;
  ControlBinop cBinop_R6ekfP52;
  ControlIf cIf_H6xLdGzv;
  ControlIf cIf_DfqhRHqO;
  ControlDelay cDelay_vtrKIoPx;
  ControlBinop cBinop_7fpAP2UT;
  ControlBinop cBinop_qGumFeV3;
  ControlIf cIf_Qx8vcvSM;
  ControlIf cIf_9wuL8x1Y;
  ControlDelay cDelay_rLDnaLFb;
  ControlBinop cBinop_dDJp6iBV;
  ControlBinop cBinop_p0bLuwlg;
  ControlIf cIf_wc5hJjmQ;
  ControlIf cIf_o2Dlx29k;
  ControlDelay cDelay_j1JMZz9w;
  ControlBinop cBinop_oOoGsf4i;
  ControlBinop cBinop_qeVRj3Lg;
  ControlIf cIf_YmtYJTvE;
  ControlIf cIf_rZAz8nHp;
  ControlDelay cDelay_F6Ei4VFN;
  ControlBinop cBinop_lEFCJ859;
  ControlBinop cBinop_Q9LPaTRE;
  ControlIf cIf_9osk8cHI;
  ControlIf cIf_EBLgVK9e;
  ControlDelay cDelay_Mwctp88J;
  ControlBinop cBinop_xpF2UHJJ;
  ControlBinop cBinop_knFXUE3B;
  ControlIf cIf_o3M58gPn;
  ControlIf cIf_vGcRtKTL;
  ControlDelay cDelay_I4IjzRNc;
  ControlBinop cBinop_GUUoqMhq;
  ControlBinop cBinop_AB77MZSe;
  SignalVarf sVarf_lPoQXBQa;
  SignalVarf sVarf_o5rS2NPL;
  SignalVarf sVarf_7o7dY1Sm;
  SignalVarf sVarf_qXFuouMu;
  SignalVarf sVarf_OrjZoUSF;
  SignalVarf sVarf_mNaJUbQ7;
  SignalVarf sVarf_kodaExi1;
  SignalVarf sVarf_gtScweVq;
  ControlVar cVar_pJsJUQWr;
  ControlSlice cSlice_orAAFeCY;
  ControlVar cVar_bzQWDuoa;
  ControlSlice cSlice_P66KE50H;
  ControlVar cVar_BCxrgBxM;
  ControlSlice cSlice_qyBPeETb;
  ControlVar cVar_RThUq8Nk;
  ControlSlice cSlice_zFcZkeTn;
  ControlVar cVar_BQmecZmK;
  ControlSlice cSlice_pDshuNln;
  ControlVar cVar_RDU0FLiT;
  ControlDelay cDelay_KXAM6s9T;
  ControlVar cVar_pi8E5Bgg;
  ControlIf cIf_8f92kS05;
  ControlIf cIf_ZId36CfC;
  ControlBinop cBinop_hQjB7UPA;
  ControlBinop cBinop_qlRITYVN;
  ControlBinop cBinop_XGqQNHEG;
  ControlBinop cBinop_FpW3GSS0;
  ControlBinop cBinop_JDpYReFN;
  ControlSlice cSlice_DiyRY5gi;
  ControlVar cVar_ziqLsgJK;
  SignalVarf sVarf_bhkLpuRW;
  SignalVarf sVarf_2wYReOrm;
  SignalVarf sVarf_mWOivtLS;
  SignalVarf sVarf_VoSWOqyN;
  SignalVarf sVarf_kzqw34n2;
  SignalVarf sVarf_aoSlpGHU;
  ControlBinop cBinop_aRtG8Dl7;
  ControlBinop cBinop_NP0b7JEp;
  ControlVar cVar_htFxCeXQ;
  ControlVar cVar_cIZo57ZY;
  ControlIf cIf_M7pdjBOC;
  ControlIf cIf_NX5gTyUc;
  ControlDelay cDelay_vNI67JXf;
  ControlBinop cBinop_qoubq9Gx;
  ControlBinop cBinop_j2CHsiau;
  ControlIf cIf_mfOMYCSR;
  ControlIf cIf_JofborWP;
  ControlDelay cDelay_EjGFuEqh;
  ControlBinop cBinop_iTLGUnDZ;
  ControlBinop cBinop_e9dAzPPL;
  ControlIf cIf_EtRSOPMi;
  ControlIf cIf_gRS9em8x;
  ControlDelay cDelay_eiTR0K1e;
  ControlBinop cBinop_iwEkfBZ8;
  ControlBinop cBinop_kNzB0FNt;
  ControlIf cIf_Fb84tml7;
  ControlIf cIf_tZIveW8w;
  ControlDelay cDelay_fbhBQuS4;
  ControlBinop cBinop_aXzuuscj;
  ControlBinop cBinop_ijAK8Iv7;
  ControlIf cIf_wrmj3ONQ;
  ControlIf cIf_SkpJZBCL;
  ControlDelay cDelay_W5kFUxjW;
  ControlBinop cBinop_KC39lpMJ;
  ControlBinop cBinop_3Uffnn3g;
  ControlIf cIf_WDGBHqdF;
  ControlIf cIf_kO22RuFm;
  ControlDelay cDelay_9qJXbjXT;
  ControlBinop cBinop_Fqq4gP8I;
  ControlBinop cBinop_CyJajx3Y;
  ControlIf cIf_SN2p3rAE;
  ControlIf cIf_rnP4gXAF;
  ControlDelay cDelay_LMJjubpX;
  ControlBinop cBinop_dLuLYpJJ;
  ControlBinop cBinop_YFrSb46i;
  ControlIf cIf_xaeGsnKc;
  ControlIf cIf_CrEqybDh;
  ControlDelay cDelay_ET3tzOis;
  ControlBinop cBinop_FkG8KS3b;
  ControlBinop cBinop_EtuSoTKW;
  ControlIf cIf_xAehWXcE;
  ControlIf cIf_jJDa0kuY;
  ControlDelay cDelay_bpilYngv;
  ControlBinop cBinop_PuA4MjCA;
  ControlBinop cBinop_5FOknQS9;
  ControlIf cIf_zPeK60qU;
  ControlIf cIf_Qo3wmeev;
  ControlDelay cDelay_JoG8HDXi;
  ControlBinop cBinop_PYZgv7EF;
  ControlBinop cBinop_2PTkaIJO;
  ControlIf cIf_4YAgU2Lo;
  ControlIf cIf_F6gViEac;
  ControlDelay cDelay_f16WWIjU;
  ControlBinop cBinop_oCTDrowa;
  ControlBinop cBinop_IUZELJUe;
  ControlIf cIf_LWrNqdVe;
  ControlIf cIf_tmZ1B9j5;
  ControlDelay cDelay_ruYDjrmD;
  ControlBinop cBinop_FcoMn8tM;
  ControlBinop cBinop_HRvlsfli;
  SignalVarf sVarf_96IIsRF2;
  SignalVarf sVarf_2pZM0lap;
  SignalVarf sVarf_eWZA6NGG;
  SignalVarf sVarf_N26gu8By;
  SignalVarf sVarf_ebw4Youd;
  SignalVarf sVarf_k4avkW2M;
  SignalVarf sVarf_dOTuhx4s;
  SignalVarf sVarf_naEhckQT;
  ControlVar cVar_ebLxwvmZ;
  ControlSlice cSlice_nAW923HN;
  ControlVar cVar_36fuV4Om;
  ControlSlice cSlice_E7XtQ40z;
  ControlVar cVar_7tFZj2P0;
  ControlSlice cSlice_KfGzKUTp;
  ControlVar cVar_fK5qLVgi;
  ControlSlice cSlice_UMuwtWbk;
  ControlVar cVar_jTI13zg5;
  ControlSlice cSlice_LuxUNe4s;
  ControlVar cVar_ypWNznak;
  ControlDelay cDelay_Af4LvOvB;
  ControlVar cVar_cuYSi4L2;
  ControlIf cIf_WeKyVdLY;
  ControlIf cIf_ws6vrIoN;
  ControlBinop cBinop_GXHWqtF9;
  ControlBinop cBinop_HHYiRvye;
  ControlBinop cBinop_vS9j5SBW;
  ControlBinop cBinop_6CGy2ryo;
  ControlBinop cBinop_ktBLRAWf;
  ControlSlice cSlice_l2I7kbWe;
  ControlVar cVar_nJWH7MIQ;
  SignalVarf sVarf_ANNDVnpM;
  SignalVarf sVarf_qMdzBEgv;
  SignalVarf sVarf_uBv8125w;
  SignalVarf sVarf_AHqxtVqH;
  SignalVarf sVarf_VrhPnmDA;
  SignalVarf sVarf_B3S3LxMo;
  ControlBinop cBinop_ZlfKcOcn;
  ControlBinop cBinop_RsoGDh9c;
  ControlVar cVar_npRP6ez2;
  SignalVarf sVarf_GwwZ7LuK;
  SignalVarf sVarf_EYrpPKDd;
  SignalVarf sVarf_VgMgMVPr;
  SignalVarf sVarf_F2V8D8kC;
  ControlBinop cBinop_EeJwixdy;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
