/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_7CYmPH9c);
  numBytes += sLine_init(&sLine_M2mowKDl);
  numBytes += sLine_init(&sLine_sJDeZ1Q2);
  numBytes += sLine_init(&sLine_kq6ik9OS);
  numBytes += sLine_init(&sLine_CNDCVGgq);
  numBytes += sLine_init(&sLine_7bwdEL1e);
  numBytes += sLine_init(&sLine_EUlYdPIc);
  numBytes += sLine_init(&sLine_CDuDlFF0);
  numBytes += sLine_init(&sLine_KDwaeqBR);
  numBytes += sLine_init(&sLine_sJEMvvnq);
  numBytes += sLine_init(&sLine_CMIZNGbb);
  numBytes += sLine_init(&sLine_nQU5ytFk);
  numBytes += sEnv_init(&sEnv_XDUJyCnX, 512, 256);
  numBytes += sEnv_init(&sEnv_5p9xpoVC, 512, 256);
  numBytes += sLine_init(&sLine_GfEjBxHa);
  numBytes += sLine_init(&sLine_wzfMWryP);
  numBytes += sLine_init(&sLine_uMU7KxTM);
  numBytes += sLine_init(&sLine_7WpoyCPh);
  numBytes += sLine_init(&sLine_DmIfd1F8);
  numBytes += sLine_init(&sLine_BhKLHbmO);
  numBytes += sLine_init(&sLine_3MBDth2m);
  numBytes += sLine_init(&sLine_vD2bKnot);
  numBytes += sLine_init(&sLine_QSlqOFyM);
  numBytes += sLine_init(&sLine_eN3lT8Js);
  numBytes += sLine_init(&sLine_QjvQ1T2b);
  numBytes += sLine_init(&sLine_q6TdOjHJ);
  numBytes += sLine_init(&sLine_ovr54S2d);
  numBytes += sLine_init(&sLine_iyFFNs4D);
  numBytes += sLine_init(&sLine_2bwywloT);
  numBytes += sLine_init(&sLine_Rx6jOTAq);
  numBytes += sLine_init(&sLine_ceF7bNRq);
  numBytes += sLine_init(&sLine_3RVs3ls9);
  numBytes += sEnv_init(&sEnv_y0FrAwLx, 512, 256);
  numBytes += sEnv_init(&sEnv_lx1xHzs9, 512, 256);
  numBytes += sLine_init(&sLine_mUR0Vm0R);
  numBytes += sLine_init(&sLine_OS8UkrNa);
  numBytes += sLine_init(&sLine_U7UvyZeY);
  numBytes += sLine_init(&sLine_4F7gYPA3);
  numBytes += sLine_init(&sLine_cMfjKoHD);
  numBytes += sLine_init(&sLine_SHZPc12Y);
  numBytes += sLine_init(&sLine_c38bwa69);
  numBytes += sLine_init(&sLine_7fO3WMiW);
  numBytes += cVar_init_f(&cVar_UVBPyGxL, 0.0f);
  numBytes += cVar_init_f(&cVar_BRLqlJoi, 0.0f);
  numBytes += cVar_init_f(&cVar_RCnhPT70, 0.0f);
  numBytes += cVar_init_f(&cVar_rTp0L0WR, 0.0f);
  numBytes += cVar_init_f(&cVar_IvXZvdQl, 0.0f);
  numBytes += cVar_init_f(&cVar_zEMvhRCB, 1.0f);
  numBytes += cVar_init_f(&cVar_kfSdvrn1, 0.0f);
  numBytes += cVar_init_f(&cVar_3yOQT6Lm, 0.0f);
  numBytes += cIf_init(&cIf_bkEyuYt9, false);
  numBytes += cIf_init(&cIf_a4vaPRBB, false);
  numBytes += cDelay_init(this, &cDelay_AovBBFA0, 10.0f);
  numBytes += cIf_init(&cIf_8PWnojB0, false);
  numBytes += cIf_init(&cIf_MeOnCuNX, false);
  numBytes += cDelay_init(this, &cDelay_i4lJlum2, 10.0f);
  numBytes += cIf_init(&cIf_a7kAEyJG, false);
  numBytes += cIf_init(&cIf_ndkOAzzN, false);
  numBytes += cDelay_init(this, &cDelay_lA3ZnZ0v, 10.0f);
  numBytes += cIf_init(&cIf_XAUFnb4T, false);
  numBytes += cIf_init(&cIf_dzlAE4oI, false);
  numBytes += cDelay_init(this, &cDelay_czpKD3qZ, 10.0f);
  numBytes += cIf_init(&cIf_g9XSgTUx, false);
  numBytes += cIf_init(&cIf_6TGav5UX, false);
  numBytes += cDelay_init(this, &cDelay_tQHuqa0U, 10.0f);
  numBytes += cIf_init(&cIf_XLgle3Om, false);
  numBytes += cIf_init(&cIf_cQcMrbIK, false);
  numBytes += cDelay_init(this, &cDelay_Nec9xF3e, 10.0f);
  numBytes += cIf_init(&cIf_H6xLdGzv, false);
  numBytes += cIf_init(&cIf_DfqhRHqO, false);
  numBytes += cDelay_init(this, &cDelay_vtrKIoPx, 10.0f);
  numBytes += cIf_init(&cIf_Qx8vcvSM, false);
  numBytes += cIf_init(&cIf_9wuL8x1Y, false);
  numBytes += cDelay_init(this, &cDelay_rLDnaLFb, 10.0f);
  numBytes += cIf_init(&cIf_wc5hJjmQ, false);
  numBytes += cIf_init(&cIf_o2Dlx29k, false);
  numBytes += cDelay_init(this, &cDelay_j1JMZz9w, 10.0f);
  numBytes += cIf_init(&cIf_YmtYJTvE, false);
  numBytes += cIf_init(&cIf_rZAz8nHp, false);
  numBytes += cDelay_init(this, &cDelay_F6Ei4VFN, 10.0f);
  numBytes += cIf_init(&cIf_9osk8cHI, false);
  numBytes += cIf_init(&cIf_EBLgVK9e, false);
  numBytes += cDelay_init(this, &cDelay_Mwctp88J, 10.0f);
  numBytes += cIf_init(&cIf_o3M58gPn, false);
  numBytes += cIf_init(&cIf_vGcRtKTL, false);
  numBytes += cDelay_init(this, &cDelay_I4IjzRNc, 10.0f);
  numBytes += sVarf_init(&sVarf_lPoQXBQa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o5rS2NPL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7o7dY1Sm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qXFuouMu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OrjZoUSF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mNaJUbQ7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kodaExi1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gtScweVq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pJsJUQWr, 0.0f);
  numBytes += cSlice_init(&cSlice_orAAFeCY, 1, -1);
  numBytes += cVar_init_f(&cVar_bzQWDuoa, 1.0f);
  numBytes += cSlice_init(&cSlice_P66KE50H, 1, -1);
  numBytes += cVar_init_f(&cVar_BCxrgBxM, 0.0f);
  numBytes += cSlice_init(&cSlice_qyBPeETb, 1, -1);
  numBytes += cVar_init_f(&cVar_RThUq8Nk, 512.0f);
  numBytes += cSlice_init(&cSlice_zFcZkeTn, 1, -1);
  numBytes += cVar_init_f(&cVar_BQmecZmK, 1.0f);
  numBytes += cSlice_init(&cSlice_pDshuNln, 1, -1);
  numBytes += cVar_init_f(&cVar_RDU0FLiT, 1.0f);
  numBytes += cDelay_init(this, &cDelay_KXAM6s9T, 20.0f);
  numBytes += cVar_init_f(&cVar_pi8E5Bgg, 0.0f);
  numBytes += cIf_init(&cIf_8f92kS05, false);
  numBytes += cIf_init(&cIf_ZId36CfC, false);
  numBytes += cBinop_init(&cBinop_hQjB7UPA, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_DiyRY5gi, 1, -1);
  numBytes += cVar_init_f(&cVar_ziqLsgJK, 0.0f);
  numBytes += sVarf_init(&sVarf_bhkLpuRW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2wYReOrm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mWOivtLS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VoSWOqyN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kzqw34n2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aoSlpGHU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_htFxCeXQ, 0.0f);
  numBytes += cVar_init_f(&cVar_cIZo57ZY, 0.0f);
  numBytes += cIf_init(&cIf_M7pdjBOC, false);
  numBytes += cIf_init(&cIf_NX5gTyUc, false);
  numBytes += cDelay_init(this, &cDelay_vNI67JXf, 10.0f);
  numBytes += cIf_init(&cIf_mfOMYCSR, false);
  numBytes += cIf_init(&cIf_JofborWP, false);
  numBytes += cDelay_init(this, &cDelay_EjGFuEqh, 10.0f);
  numBytes += cIf_init(&cIf_EtRSOPMi, false);
  numBytes += cIf_init(&cIf_gRS9em8x, false);
  numBytes += cDelay_init(this, &cDelay_eiTR0K1e, 10.0f);
  numBytes += cIf_init(&cIf_Fb84tml7, false);
  numBytes += cIf_init(&cIf_tZIveW8w, false);
  numBytes += cDelay_init(this, &cDelay_fbhBQuS4, 10.0f);
  numBytes += cIf_init(&cIf_wrmj3ONQ, false);
  numBytes += cIf_init(&cIf_SkpJZBCL, false);
  numBytes += cDelay_init(this, &cDelay_W5kFUxjW, 10.0f);
  numBytes += cIf_init(&cIf_WDGBHqdF, false);
  numBytes += cIf_init(&cIf_kO22RuFm, false);
  numBytes += cDelay_init(this, &cDelay_9qJXbjXT, 10.0f);
  numBytes += cIf_init(&cIf_SN2p3rAE, false);
  numBytes += cIf_init(&cIf_rnP4gXAF, false);
  numBytes += cDelay_init(this, &cDelay_LMJjubpX, 10.0f);
  numBytes += cIf_init(&cIf_xaeGsnKc, false);
  numBytes += cIf_init(&cIf_CrEqybDh, false);
  numBytes += cDelay_init(this, &cDelay_ET3tzOis, 10.0f);
  numBytes += cIf_init(&cIf_xAehWXcE, false);
  numBytes += cIf_init(&cIf_jJDa0kuY, false);
  numBytes += cDelay_init(this, &cDelay_bpilYngv, 10.0f);
  numBytes += cIf_init(&cIf_zPeK60qU, false);
  numBytes += cIf_init(&cIf_Qo3wmeev, false);
  numBytes += cDelay_init(this, &cDelay_JoG8HDXi, 10.0f);
  numBytes += cIf_init(&cIf_4YAgU2Lo, false);
  numBytes += cIf_init(&cIf_F6gViEac, false);
  numBytes += cDelay_init(this, &cDelay_f16WWIjU, 10.0f);
  numBytes += cIf_init(&cIf_LWrNqdVe, false);
  numBytes += cIf_init(&cIf_tmZ1B9j5, false);
  numBytes += cDelay_init(this, &cDelay_ruYDjrmD, 10.0f);
  numBytes += sVarf_init(&sVarf_96IIsRF2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2pZM0lap, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eWZA6NGG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N26gu8By, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ebw4Youd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k4avkW2M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dOTuhx4s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_naEhckQT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ebLxwvmZ, 0.0f);
  numBytes += cSlice_init(&cSlice_nAW923HN, 1, -1);
  numBytes += cVar_init_f(&cVar_36fuV4Om, 1.0f);
  numBytes += cSlice_init(&cSlice_E7XtQ40z, 1, -1);
  numBytes += cVar_init_f(&cVar_7tFZj2P0, 0.0f);
  numBytes += cSlice_init(&cSlice_KfGzKUTp, 1, -1);
  numBytes += cVar_init_f(&cVar_fK5qLVgi, 512.0f);
  numBytes += cSlice_init(&cSlice_UMuwtWbk, 1, -1);
  numBytes += cVar_init_f(&cVar_jTI13zg5, 1.0f);
  numBytes += cSlice_init(&cSlice_LuxUNe4s, 1, -1);
  numBytes += cVar_init_f(&cVar_ypWNznak, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Af4LvOvB, 20.0f);
  numBytes += cVar_init_f(&cVar_cuYSi4L2, 0.0f);
  numBytes += cIf_init(&cIf_WeKyVdLY, false);
  numBytes += cIf_init(&cIf_ws6vrIoN, false);
  numBytes += cBinop_init(&cBinop_GXHWqtF9, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_l2I7kbWe, 1, -1);
  numBytes += cVar_init_f(&cVar_nJWH7MIQ, 0.0f);
  numBytes += sVarf_init(&sVarf_ANNDVnpM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qMdzBEgv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uBv8125w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AHqxtVqH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VrhPnmDA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B3S3LxMo, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_npRP6ez2, 0.0f);
  numBytes += sVarf_init(&sVarf_GwwZ7LuK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EYrpPKDd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VgMgMVPr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F2V8D8kC, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_XDUJyCnX);
  sEnv_free(&sEnv_5p9xpoVC);
  sEnv_free(&sEnv_y0FrAwLx);
  sEnv_free(&sEnv_lx1xHzs9);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vl0u6dsT_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HAKUnE9S_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R1NMWyCy_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kRO2Njba_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uHsdGA6w_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lqrEN6ys_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fUNexbCk_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F1P9phkF_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RMw8wVGz_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rxwMRWKG_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WmcLpa1I_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jI8hNGWY_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_digrYlp4_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZGYlasyG_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UPOJ9q4U_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0RAhRzT7_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3mnP7EhX_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DxuiZN6K_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nhAve4l7_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mDMgPr9k_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8LN2Q7Zd_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_UVBPyGxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4HC8ZGJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_euJTJVVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dDR7cGbA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dDR7cGbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_g9R6fbBW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_g9R6fbBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_imyoW4DL_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_imyoW4DL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wotaj0sA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PPqZWOkT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PPqZWOkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EhP55das_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_wotaj0sA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_v3rbAjwu_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_v3rbAjwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MPZvBgy3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EhP55das_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DsnAWKfI_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DsnAWKfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pnvv56Hn_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_MPZvBgy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7cbMbEdq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_pnvv56Hn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ht7kIrJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_BRLqlJoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CdWAYdsi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_RCnhPT70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5tb4MAb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_rTp0L0WR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3XLaRrcE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_IvXZvdQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wcl3zw5p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_zEMvhRCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vRCLCpJm_sendMessage);
  cMsg_g16S0ohF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_vRCLCpJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zEMvhRCB, 1, m, &cVar_zEMvhRCB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qH9uqMoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rpWnEasn_sendMessage(_c, 0, m);
  cMsg_9w7NNbBT_sendMessage(_c, 0, m);
  cMsg_ZFkSvyvm_sendMessage(_c, 0, m);
  cMsg_r9uYT2d7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_kfSdvrn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9tprvi5t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_3yOQT6Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZnM6pi2X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_2a29g6EB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VeAslTpC_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S4mAubXX_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9mYDL8zN_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gMeglFbp_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hy9Rv6eU_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ay74qSvm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_VeAslTpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eAIXhpYM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_S4mAubXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ydz2rSPK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_9mYDL8zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_THME8nTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_gMeglFbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FSEfB4kZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_hy9Rv6eU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gp7vSUNP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_ay74qSvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ogfDQKOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_bkEyuYt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cWxIsQvu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_a4vaPRBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xI3ZGmLB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7zNMPa90_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EyW3kH6R_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EyW3kH6R_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AovBBFA0, 1, m, &cDelay_AovBBFA0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_73A49K4l_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_AovBBFA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AovBBFA0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bkEyuYt9, 0, m, &cIf_bkEyuYt9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EyW3kH6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AovBBFA0, 0, m, &cDelay_AovBBFA0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_73A49K4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AovBBFA0, 0, m, &cDelay_AovBBFA0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LHV0btf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GV1L14ga_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gmyu3H1q_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oe9fWCYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4BoFCNCe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wyWNhpOe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4BoFCNCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bkEyuYt9, 1, m, &cIf_bkEyuYt9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wyWNhpOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7zNMPa90_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_GV1L14ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a4vaPRBB, 1, m, &cIf_a4vaPRBB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gmyu3H1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a4vaPRBB, 0, m, &cIf_a4vaPRBB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xI3ZGmLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kq6ik9OS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cWxIsQvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kq6ik9OS, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_8PWnojB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_idci1RXL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_MeOnCuNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lvg64PZ5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_CttjiQBN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AGEnDE1h_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AGEnDE1h_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_i4lJlum2, 1, m, &cDelay_i4lJlum2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TbeAEtDV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_i4lJlum2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_i4lJlum2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8PWnojB0, 0, m, &cIf_8PWnojB0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AGEnDE1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_i4lJlum2, 0, m, &cDelay_i4lJlum2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TbeAEtDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_i4lJlum2, 0, m, &cDelay_i4lJlum2_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_b9hAcDI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fu5oWcjB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E0Yn0dgw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7jH9sZmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TQLNF5NL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nMz6Pepx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TQLNF5NL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8PWnojB0, 1, m, &cIf_8PWnojB0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nMz6Pepx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CttjiQBN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Fu5oWcjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MeOnCuNX, 1, m, &cIf_MeOnCuNX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_E0Yn0dgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MeOnCuNX, 0, m, &cIf_MeOnCuNX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lvg64PZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EUlYdPIc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_idci1RXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EUlYdPIc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_a7kAEyJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HwHUgsum_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ndkOAzzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Zce3J0KU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_It2xytWu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XbwRhOik_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XbwRhOik_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lA3ZnZ0v, 1, m, &cDelay_lA3ZnZ0v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oGf50rW9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lA3ZnZ0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lA3ZnZ0v, m);
  cIf_onMessage(_c, &Context(_c)->cIf_a7kAEyJG, 0, m, &cIf_a7kAEyJG_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XbwRhOik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lA3ZnZ0v, 0, m, &cDelay_lA3ZnZ0v_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oGf50rW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lA3ZnZ0v, 0, m, &cDelay_lA3ZnZ0v_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jw6q25MC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tmoUb8U8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8WCVt6jZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2nPIUMvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4M64ZniY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jOwfSNdy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4M64ZniY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a7kAEyJG, 1, m, &cIf_a7kAEyJG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jOwfSNdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_It2xytWu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_tmoUb8U8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ndkOAzzN, 1, m, &cIf_ndkOAzzN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8WCVt6jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ndkOAzzN, 0, m, &cIf_ndkOAzzN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Zce3J0KU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sJEMvvnq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_HwHUgsum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sJEMvvnq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_XAUFnb4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IKhwzjkC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_dzlAE4oI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IzSBbW5g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_BVEHbvI2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CqttxXwp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CqttxXwp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_czpKD3qZ, 1, m, &cDelay_czpKD3qZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qfDumyIq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_czpKD3qZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_czpKD3qZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XAUFnb4T, 0, m, &cIf_XAUFnb4T_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_CqttxXwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_czpKD3qZ, 0, m, &cDelay_czpKD3qZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qfDumyIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_czpKD3qZ, 0, m, &cDelay_czpKD3qZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7fDftAF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U8w15t9E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0jV1V5ki_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mS84Lclo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_URP6P3gj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pq4F3zSB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pq4F3zSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BVEHbvI2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_URP6P3gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XAUFnb4T, 1, m, &cIf_XAUFnb4T_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_U8w15t9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dzlAE4oI, 1, m, &cIf_dzlAE4oI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0jV1V5ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dzlAE4oI, 0, m, &cIf_dzlAE4oI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IzSBbW5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CNDCVGgq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_IKhwzjkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CNDCVGgq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_g9XSgTUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_t4DGmfmW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6TGav5UX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3ctRGjDF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_dMLjhOmN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NzDhoKFX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NzDhoKFX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tQHuqa0U, 1, m, &cDelay_tQHuqa0U_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ulj5Hy18_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_tQHuqa0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tQHuqa0U, m);
  cIf_onMessage(_c, &Context(_c)->cIf_g9XSgTUx, 0, m, &cIf_g9XSgTUx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NzDhoKFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tQHuqa0U, 0, m, &cDelay_tQHuqa0U_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ulj5Hy18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tQHuqa0U, 0, m, &cDelay_tQHuqa0U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VxJwDQrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JuMk3s25_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AicimXri_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iylZ0nOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sWHfBk3Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghLxTB4H_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ghLxTB4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dMLjhOmN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_sWHfBk3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g9XSgTUx, 1, m, &cIf_g9XSgTUx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AicimXri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6TGav5UX, 0, m, &cIf_6TGav5UX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JuMk3s25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6TGav5UX, 1, m, &cIf_6TGav5UX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3ctRGjDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CDuDlFF0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_t4DGmfmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CDuDlFF0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_XLgle3Om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xEgycUIf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_cQcMrbIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UYwMXMWX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ZtB3AOlw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wFlUlTVb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wFlUlTVb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Nec9xF3e, 1, m, &cDelay_Nec9xF3e_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I9ngjZWi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Nec9xF3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Nec9xF3e, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XLgle3Om, 0, m, &cIf_XLgle3Om_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wFlUlTVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nec9xF3e, 0, m, &cDelay_Nec9xF3e_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_I9ngjZWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Nec9xF3e, 0, m, &cDelay_Nec9xF3e_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_THqmVpsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wchuX93u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g2uZhkW0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_R6ekfP52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3DhQdAlj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NPIeF8o6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NPIeF8o6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZtB3AOlw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_3DhQdAlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XLgle3Om, 1, m, &cIf_XLgle3Om_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_g2uZhkW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cQcMrbIK, 0, m, &cIf_cQcMrbIK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wchuX93u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cQcMrbIK, 1, m, &cIf_cQcMrbIK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UYwMXMWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CMIZNGbb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xEgycUIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CMIZNGbb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_H6xLdGzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gUT0VI35_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DfqhRHqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SHjkXhLS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_adtPpo7E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_k7olnrlE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_k7olnrlE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vtrKIoPx, 1, m, &cDelay_vtrKIoPx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MR7W3ywe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vtrKIoPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vtrKIoPx, m);
  cIf_onMessage(_c, &Context(_c)->cIf_H6xLdGzv, 0, m, &cIf_H6xLdGzv_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_k7olnrlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vtrKIoPx, 0, m, &cDelay_vtrKIoPx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MR7W3ywe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vtrKIoPx, 0, m, &cDelay_vtrKIoPx_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7fpAP2UT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OmPwJd6I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hh6WqnQ0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qGumFeV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RyxhkfIV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CHPxug00_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CHPxug00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_adtPpo7E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_RyxhkfIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H6xLdGzv, 1, m, &cIf_H6xLdGzv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Hh6WqnQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DfqhRHqO, 0, m, &cIf_DfqhRHqO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OmPwJd6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DfqhRHqO, 1, m, &cIf_DfqhRHqO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SHjkXhLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7bwdEL1e, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gUT0VI35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7bwdEL1e, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Qx8vcvSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AFofeXFf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_9wuL8x1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6QxLAOkj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_PFEto2iQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_psTHmoHk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_psTHmoHk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rLDnaLFb, 1, m, &cDelay_rLDnaLFb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_URKIcWhu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_rLDnaLFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rLDnaLFb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Qx8vcvSM, 0, m, &cIf_Qx8vcvSM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_psTHmoHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rLDnaLFb, 0, m, &cDelay_rLDnaLFb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_URKIcWhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rLDnaLFb, 0, m, &cDelay_rLDnaLFb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dDJp6iBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vtcRoG1N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UiJ9sQiA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_p0bLuwlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ec4zcPa7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fpnroa75_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Ec4zcPa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qx8vcvSM, 1, m, &cIf_Qx8vcvSM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Fpnroa75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PFEto2iQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_vtcRoG1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9wuL8x1Y, 1, m, &cIf_9wuL8x1Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UiJ9sQiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9wuL8x1Y, 0, m, &cIf_9wuL8x1Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6QxLAOkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KDwaeqBR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AFofeXFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KDwaeqBR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_wc5hJjmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rFjI23eE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_o2Dlx29k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_K5UXoDvr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Ddz8W2Rj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nBtjmar7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nBtjmar7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_j1JMZz9w, 1, m, &cDelay_j1JMZz9w_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1Ygf4LYy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_j1JMZz9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j1JMZz9w, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wc5hJjmQ, 0, m, &cIf_wc5hJjmQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nBtjmar7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1JMZz9w, 0, m, &cDelay_j1JMZz9w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1Ygf4LYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_j1JMZz9w, 0, m, &cDelay_j1JMZz9w_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oOoGsf4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kskLo51O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AXa4ovv1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qeVRj3Lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QjjTGYJh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghFF6k3b_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QjjTGYJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wc5hJjmQ, 1, m, &cIf_wc5hJjmQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ghFF6k3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ddz8W2Rj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_kskLo51O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o2Dlx29k, 1, m, &cIf_o2Dlx29k_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AXa4ovv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o2Dlx29k, 0, m, &cIf_o2Dlx29k_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_K5UXoDvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nQU5ytFk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rFjI23eE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nQU5ytFk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_YmtYJTvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EDA9ENAy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_rZAz8nHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L8DBYL8X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_rO69k2H2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wXc6EqxK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wXc6EqxK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_F6Ei4VFN, 1, m, &cDelay_F6Ei4VFN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Rne9swN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_F6Ei4VFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F6Ei4VFN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YmtYJTvE, 0, m, &cIf_YmtYJTvE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wXc6EqxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_F6Ei4VFN, 0, m, &cDelay_F6Ei4VFN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5Rne9swN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_F6Ei4VFN, 0, m, &cDelay_F6Ei4VFN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_lEFCJ859_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ftKZkAtL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_82qdlfKj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Q9LPaTRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gjfEajOt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BqT38R4B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BqT38R4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rO69k2H2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_gjfEajOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YmtYJTvE, 1, m, &cIf_YmtYJTvE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_82qdlfKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZAz8nHp, 0, m, &cIf_rZAz8nHp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ftKZkAtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZAz8nHp, 1, m, &cIf_rZAz8nHp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L8DBYL8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7CYmPH9c, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_EDA9ENAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7CYmPH9c, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_9osk8cHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OC9kbWvn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_EBLgVK9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bQQoA8ko_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_YxVG1h7Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_faF1KyWG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_faF1KyWG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Mwctp88J, 1, m, &cDelay_Mwctp88J_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GEtpIipS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Mwctp88J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Mwctp88J, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9osk8cHI, 0, m, &cIf_9osk8cHI_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_faF1KyWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mwctp88J, 0, m, &cDelay_Mwctp88J_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GEtpIipS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Mwctp88J, 0, m, &cDelay_Mwctp88J_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xpF2UHJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2jo6f0OV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CD8hCFZS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_knFXUE3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tlJkcFem_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cwl3pYSU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tlJkcFem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9osk8cHI, 1, m, &cIf_9osk8cHI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cwl3pYSU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YxVG1h7Z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_2jo6f0OV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EBLgVK9e, 1, m, &cIf_EBLgVK9e_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CD8hCFZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EBLgVK9e, 0, m, &cIf_EBLgVK9e_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bQQoA8ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M2mowKDl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_OC9kbWvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M2mowKDl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_o3M58gPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5EShUZFY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_vGcRtKTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_abliledI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_2qFlc0GD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fJdLTN7F_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fJdLTN7F_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_I4IjzRNc, 1, m, &cDelay_I4IjzRNc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OUSPFOBb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_I4IjzRNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I4IjzRNc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_o3M58gPn, 0, m, &cIf_o3M58gPn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fJdLTN7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_I4IjzRNc, 0, m, &cDelay_I4IjzRNc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OUSPFOBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I4IjzRNc, 0, m, &cDelay_I4IjzRNc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GUUoqMhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bLJdsvGw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_po8An6mt_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AB77MZSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xHfoeKgZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n8mVFAD1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_n8mVFAD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2qFlc0GD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_xHfoeKgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o3M58gPn, 1, m, &cIf_o3M58gPn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bLJdsvGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGcRtKTL, 1, m, &cIf_vGcRtKTL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_po8An6mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGcRtKTL, 0, m, &cIf_vGcRtKTL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_abliledI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sJDeZ1Q2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_5EShUZFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sJDeZ1Q2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eAIXhpYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_yTzmTflb_sendMessage(_c, 0, m);
  cMsg_sDhe9BbX_sendMessage(_c, 0, m);
  cMsg_Ct3qqmK7_sendMessage(_c, 0, m);
  cMsg_T199aLgo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Ydz2rSPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_yTzmTflb_sendMessage(_c, 0, m);
  cMsg_yqcxhaOd_sendMessage(_c, 0, m);
  cMsg_AnRLaulc_sendMessage(_c, 0, m);
  cMsg_7e1TXQj1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_THME8nTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_SuR0cBTQ_sendMessage(_c, 0, m);
  cMsg_yqcxhaOd_sendMessage(_c, 0, m);
  cMsg_T199aLgo_sendMessage(_c, 0, m);
  cMsg_b7diI1vu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_FSEfB4kZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_SuR0cBTQ_sendMessage(_c, 0, m);
  cMsg_0NkABrV1_sendMessage(_c, 0, m);
  cMsg_Ct3qqmK7_sendMessage(_c, 0, m);
  cMsg_o5PjqcnV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_gp7vSUNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_WeMopQq9_sendMessage(_c, 0, m);
  cMsg_7e1TXQj1_sendMessage(_c, 0, m);
  cMsg_a80Z1ZMS_sendMessage(_c, 0, m);
  cMsg_Ct3qqmK7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ogfDQKOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_WeMopQq9_sendMessage(_c, 0, m);
  cMsg_o5PjqcnV_sendMessage(_c, 0, m);
  cMsg_yqcxhaOd_sendMessage(_c, 0, m);
  cMsg_OBZyK9D1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BSW8WaOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oe9fWCYW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LHV0btf3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xQXIsK42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oe9fWCYW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LHV0btf3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XXE02jYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jH9sZmR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_b9hAcDI5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZOn9Ybzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7jH9sZmR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_b9hAcDI5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_w8FjVf5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2nPIUMvq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jw6q25MC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WQ8e7QfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2nPIUMvq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jw6q25MC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yTzmTflb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_BSW8WaOx_sendMessage(_c, 0, m);
  cMsg_ZOn9Ybzb_sendMessage(_c, 0, m);
  cMsg_WQ8e7QfY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_SuR0cBTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_xQXIsK42_sendMessage(_c, 0, m);
  cMsg_XXE02jYh_sendMessage(_c, 0, m);
  cMsg_WQ8e7QfY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WeMopQq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_xQXIsK42_sendMessage(_c, 0, m);
  cMsg_ZOn9Ybzb_sendMessage(_c, 0, m);
  cMsg_w8FjVf5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UmrhPkaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mS84Lclo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7fDftAF5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zTUGXTrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mS84Lclo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7fDftAF5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aJSDTzpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iylZ0nOq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VxJwDQrP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7Y18ZYQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iylZ0nOq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VxJwDQrP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_irzsAnxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R6ekfP52_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_THqmVpsr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wh1VF8aw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R6ekfP52_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_THqmVpsr_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yqcxhaOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_zTUGXTrI_sendMessage(_c, 0, m);
  cMsg_7Y18ZYQi_sendMessage(_c, 0, m);
  cMsg_wh1VF8aw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_sDhe9BbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_zTUGXTrI_sendMessage(_c, 0, m);
  cMsg_aJSDTzpg_sendMessage(_c, 0, m);
  cMsg_irzsAnxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0NkABrV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_UmrhPkaJ_sendMessage(_c, 0, m);
  cMsg_7Y18ZYQi_sendMessage(_c, 0, m);
  cMsg_irzsAnxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_66cf7POo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q9LPaTRE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lEFCJ859_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qw6ABwe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Q9LPaTRE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lEFCJ859_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9iphVohR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_knFXUE3B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xpF2UHJJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eSpQ4dbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_knFXUE3B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xpF2UHJJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XC1fJ2Kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AB77MZSe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GUUoqMhq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ceJ3LGcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AB77MZSe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GUUoqMhq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o5PjqcnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_66cf7POo_sendMessage(_c, 0, m);
  cMsg_eSpQ4dbR_sendMessage(_c, 0, m);
  cMsg_ceJ3LGcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7e1TXQj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_qw6ABwe0_sendMessage(_c, 0, m);
  cMsg_9iphVohR_sendMessage(_c, 0, m);
  cMsg_ceJ3LGcx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_T199aLgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_qw6ABwe0_sendMessage(_c, 0, m);
  cMsg_eSpQ4dbR_sendMessage(_c, 0, m);
  cMsg_XC1fJ2Kf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0gmKwJiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qGumFeV3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7fpAP2UT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_R1sMVyCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qGumFeV3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7fpAP2UT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_S7pRVIh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p0bLuwlg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dDJp6iBV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_liFm2D8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p0bLuwlg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dDJp6iBV_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_I0YIDAZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qeVRj3Lg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oOoGsf4i_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3K2QFzgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qeVRj3Lg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oOoGsf4i_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ct3qqmK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_R1sMVyCu_sendMessage(_c, 0, m);
  cMsg_liFm2D8M_sendMessage(_c, 0, m);
  cMsg_3K2QFzgF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_AnRLaulc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_R1sMVyCu_sendMessage(_c, 0, m);
  cMsg_S7pRVIh2_sendMessage(_c, 0, m);
  cMsg_I0YIDAZd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_OBZyK9D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_0gmKwJiE_sendMessage(_c, 0, m);
  cMsg_S7pRVIh2_sendMessage(_c, 0, m);
  cMsg_3K2QFzgF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_a80Z1ZMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_UmrhPkaJ_sendMessage(_c, 0, m);
  cMsg_aJSDTzpg_sendMessage(_c, 0, m);
  cMsg_wh1VF8aw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_b7diI1vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_0gmKwJiE_sendMessage(_c, 0, m);
  cMsg_liFm2D8M_sendMessage(_c, 0, m);
  cMsg_I0YIDAZd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_pJsJUQWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ans4wfFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Rb5btp3X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_orAAFeCY, 0, m, &cSlice_orAAFeCY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aqU92NyX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_orAAFeCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_703amVLS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_703amVLS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_bzQWDuoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_703amVLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_703amVLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rxwMRWKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_UpyXTIjK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P66KE50H, 0, m, &cSlice_P66KE50H_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1996gANF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_P66KE50H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mlONwrGv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mlONwrGv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_BCxrgBxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mlONwrGv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_mlONwrGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZGYlasyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_1996gANF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qyBPeETb, 0, m, &cSlice_qyBPeETb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Rb5btp3X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_qyBPeETb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9r25a2N7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9r25a2N7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_RThUq8Nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9r25a2N7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_9r25a2N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RMw8wVGz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_aqU92NyX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zFcZkeTn, 0, m, &cSlice_zFcZkeTn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KZg6MkXc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_zFcZkeTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vmXhZreK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vmXhZreK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_BQmecZmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vmXhZreK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_vmXhZreK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_digrYlp4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_KZg6MkXc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pDshuNln, 0, m, &cSlice_pDshuNln_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HKaraOV4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_pDshuNln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_p5GlXw2x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_p5GlXw2x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_RDU0FLiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p5GlXw2x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_p5GlXw2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jI8hNGWY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_1rffhhhK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rk4xMqC0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rk4xMqC0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KXAM6s9T, 1, m, &cDelay_KXAM6s9T_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sF3dkKRa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_KXAM6s9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KXAM6s9T, m);
  cMsg_N1l1Vvcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rk4xMqC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KXAM6s9T, 0, m, &cDelay_KXAM6s9T_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sF3dkKRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KXAM6s9T, 0, m, &cDelay_KXAM6s9T_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_pi8E5Bgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQjB7UPA, HV_BINOP_SUBTRACT, 0, m, &cBinop_hQjB7UPA_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_8f92kS05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ajGAm4Js_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ZId36CfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ajGAm4Js_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_XDUJyCnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pi8E5Bgg, 0, m, &cVar_pi8E5Bgg_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_5p9xpoVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MHQnmeo9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y8b87xS4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gNHtpeV0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hQjB7UPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x7asQgCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_x7asQgCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qlRITYVN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qlRITYVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_JDpYReFN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XGqQNHEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F3UBBQ47_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TtmIGflA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TtmIGflA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vM2F88qk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_F3UBBQ47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8f92kS05, 1, m, &cIf_8f92kS05_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FpW3GSS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZId36CfC, 1, m, &cIf_ZId36CfC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vM2F88qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_8f92kS05, 0, m, &cIf_8f92kS05_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JDpYReFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZId36CfC, 0, m, &cIf_ZId36CfC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_y8b87xS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hQjB7UPA, HV_BINOP_SUBTRACT, 1, m, &cBinop_hQjB7UPA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MHQnmeo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_gNHtpeV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pi8E5Bgg, 0, m, &cVar_pi8E5Bgg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ajGAm4Js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GfEjBxHa, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_HKaraOV4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DiyRY5gi, 0, m, &cSlice_DiyRY5gi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_DiyRY5gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_goYX5nTj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_goYX5nTj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_ziqLsgJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_goYX5nTj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_goYX5nTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WmcLpa1I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9tprvi5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BhKLHbmO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ZnM6pi2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7WpoyCPh, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_aRtG8Dl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3yOQT6Lm, 0, m, &cVar_3yOQT6Lm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ans4wfFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DmIfd1F8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_3O7DtM8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2HO8rlG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_JZqxHGrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1rffhhhK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_N1l1Vvcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wzfMWryP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_2HO8rlG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wzfMWryP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Yu7omDfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_NP0b7JEp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_NP0b7JEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tWozNNvv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tWozNNvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uMU7KxTM, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_htFxCeXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UlAmMIHd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_cIZo57ZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uz2J8gpj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Tm2HeCcD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uMjdHhfp_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PJLI8LSC_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BaL7l1PA_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgRbj0LX_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gk6GDTeJ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HwufovAs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_uMjdHhfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bOVx7f94_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_PJLI8LSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jCvBmojD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_BaL7l1PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vvvQcVbV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_vgRbj0LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cY1sLx9L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_gk6GDTeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HwmRhup2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_HwufovAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JIjpQhWN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_M7pdjBOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YsSXUvfU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_NX5gTyUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A4tL90yi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_xl3TyaSa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0kcd7wcN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0kcd7wcN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vNI67JXf, 1, m, &cDelay_vNI67JXf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rxiCPymf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vNI67JXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vNI67JXf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_M7pdjBOC, 0, m, &cIf_M7pdjBOC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0kcd7wcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vNI67JXf, 0, m, &cDelay_vNI67JXf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rxiCPymf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vNI67JXf, 0, m, &cDelay_vNI67JXf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qoubq9Gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HlJmeLXb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SNZNegu5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_j2CHsiau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OC5c4Yw6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ki5jmLkT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ki5jmLkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xl3TyaSa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_OC5c4Yw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M7pdjBOC, 1, m, &cIf_M7pdjBOC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SNZNegu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NX5gTyUc, 0, m, &cIf_NX5gTyUc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HlJmeLXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NX5gTyUc, 1, m, &cIf_NX5gTyUc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_A4tL90yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eN3lT8Js, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_YsSXUvfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eN3lT8Js, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_mfOMYCSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_V3vYodht_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_JofborWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w3wCwise_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_siO4NGB4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AS7y6z7F_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AS7y6z7F_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EjGFuEqh, 1, m, &cDelay_EjGFuEqh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZFoTbLrb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_EjGFuEqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EjGFuEqh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mfOMYCSR, 0, m, &cIf_mfOMYCSR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AS7y6z7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EjGFuEqh, 0, m, &cDelay_EjGFuEqh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ZFoTbLrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EjGFuEqh, 0, m, &cDelay_EjGFuEqh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iTLGUnDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p3wKuE3A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f6So2TNb_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_e9dAzPPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n2NepWli_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LHMNQbOH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LHMNQbOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_siO4NGB4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_n2NepWli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mfOMYCSR, 1, m, &cIf_mfOMYCSR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_f6So2TNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JofborWP, 0, m, &cIf_JofborWP_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_p3wKuE3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JofborWP, 1, m, &cIf_JofborWP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_w3wCwise_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ovr54S2d, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_V3vYodht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ovr54S2d, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_EtRSOPMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CpKiYGgC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gRS9em8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_P7Kn0tBd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_50gr4ljl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tyxm0jZv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tyxm0jZv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eiTR0K1e, 1, m, &cDelay_eiTR0K1e_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ChNyqvxv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_eiTR0K1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eiTR0K1e, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EtRSOPMi, 0, m, &cIf_EtRSOPMi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tyxm0jZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eiTR0K1e, 0, m, &cDelay_eiTR0K1e_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ChNyqvxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eiTR0K1e, 0, m, &cDelay_eiTR0K1e_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iwEkfBZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K4c9WLEc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AQhf57oZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kNzB0FNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AkJlzyOf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T2g0lOgC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T2g0lOgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_50gr4ljl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AkJlzyOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EtRSOPMi, 1, m, &cIf_EtRSOPMi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AQhf57oZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gRS9em8x, 0, m, &cIf_gRS9em8x_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_K4c9WLEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gRS9em8x, 1, m, &cIf_gRS9em8x_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_P7Kn0tBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rx6jOTAq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_CpKiYGgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rx6jOTAq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Fb84tml7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XljweFOu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tZIveW8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2RlmBrn6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_r4GpJXSt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tGoa7wD3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tGoa7wD3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fbhBQuS4, 1, m, &cDelay_fbhBQuS4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4kUV3JMe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_fbhBQuS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fbhBQuS4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Fb84tml7, 0, m, &cIf_Fb84tml7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tGoa7wD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fbhBQuS4, 0, m, &cDelay_fbhBQuS4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4kUV3JMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fbhBQuS4, 0, m, &cDelay_fbhBQuS4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aXzuuscj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1L0SGwXv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n9OICG9Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ijAK8Iv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mo0ZxW81_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XU1fxqqh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mo0ZxW81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fb84tml7, 1, m, &cIf_Fb84tml7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XU1fxqqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_r4GpJXSt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_n9OICG9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tZIveW8w, 0, m, &cIf_tZIveW8w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1L0SGwXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tZIveW8w, 1, m, &cIf_tZIveW8w_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_2RlmBrn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QjvQ1T2b, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_XljweFOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QjvQ1T2b, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_wrmj3ONQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E8hMpCGR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_SkpJZBCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DSBbVXts_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ieeE1Ouz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_j83kAELU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_j83kAELU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_W5kFUxjW, 1, m, &cDelay_W5kFUxjW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vEFkmvgW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_W5kFUxjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W5kFUxjW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wrmj3ONQ, 0, m, &cIf_wrmj3ONQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_j83kAELU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_W5kFUxjW, 0, m, &cDelay_W5kFUxjW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vEFkmvgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_W5kFUxjW, 0, m, &cDelay_W5kFUxjW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KC39lpMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AfgG88Ji_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1BKspfTY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3Uffnn3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E0inN2o1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fk88EZY6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_E0inN2o1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wrmj3ONQ, 1, m, &cIf_wrmj3ONQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_fk88EZY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ieeE1Ouz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_AfgG88Ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SkpJZBCL, 1, m, &cIf_SkpJZBCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1BKspfTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SkpJZBCL, 0, m, &cIf_SkpJZBCL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DSBbVXts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iyFFNs4D, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_E8hMpCGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iyFFNs4D, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_WDGBHqdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4VCE0yfQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_kO22RuFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3QcFN0vE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_V4oej15s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SQekpepI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SQekpepI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9qJXbjXT, 1, m, &cDelay_9qJXbjXT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_otVoNj4C_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_9qJXbjXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9qJXbjXT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WDGBHqdF, 0, m, &cIf_WDGBHqdF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SQekpepI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9qJXbjXT, 0, m, &cDelay_9qJXbjXT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_otVoNj4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9qJXbjXT, 0, m, &cDelay_9qJXbjXT_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Fqq4gP8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JzsDKSNP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dmljptMJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CyJajx3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IDXotq9R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_foCt7OdC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IDXotq9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WDGBHqdF, 1, m, &cIf_WDGBHqdF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_foCt7OdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V4oej15s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JzsDKSNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kO22RuFm, 1, m, &cIf_kO22RuFm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dmljptMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kO22RuFm, 0, m, &cIf_kO22RuFm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3QcFN0vE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ceF7bNRq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_4VCE0yfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ceF7bNRq, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_SN2p3rAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GdhrrKmr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_rnP4gXAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_urYOnV8E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_f1uyLHPp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_b9pWZ8Q1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_b9pWZ8Q1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LMJjubpX, 1, m, &cDelay_LMJjubpX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0gclJtCl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_LMJjubpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LMJjubpX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SN2p3rAE, 0, m, &cIf_SN2p3rAE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_b9pWZ8Q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LMJjubpX, 0, m, &cDelay_LMJjubpX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0gclJtCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LMJjubpX, 0, m, &cDelay_LMJjubpX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dLuLYpJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TuFjDSCc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ejwLzsqY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YFrSb46i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MKEIwumx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_plbXim5b_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_plbXim5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_f1uyLHPp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_MKEIwumx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SN2p3rAE, 1, m, &cIf_SN2p3rAE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ejwLzsqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rnP4gXAF, 0, m, &cIf_rnP4gXAF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TuFjDSCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rnP4gXAF, 1, m, &cIf_rnP4gXAF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_urYOnV8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q6TdOjHJ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GdhrrKmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q6TdOjHJ, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xaeGsnKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ej0KXCFt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_CrEqybDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L32w6Qnx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Cz7cMyn7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4zavIzD0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4zavIzD0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ET3tzOis, 1, m, &cDelay_ET3tzOis_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SrAAOunf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ET3tzOis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ET3tzOis, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xaeGsnKc, 0, m, &cIf_xaeGsnKc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4zavIzD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ET3tzOis, 0, m, &cDelay_ET3tzOis_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SrAAOunf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ET3tzOis, 0, m, &cDelay_ET3tzOis_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FkG8KS3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HAffUcJu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vWaP1WYf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_EtuSoTKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1mv13FS2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EdrnjQnH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1mv13FS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xaeGsnKc, 1, m, &cIf_xaeGsnKc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EdrnjQnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Cz7cMyn7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_vWaP1WYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CrEqybDh, 0, m, &cIf_CrEqybDh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HAffUcJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CrEqybDh, 1, m, &cIf_CrEqybDh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L32w6Qnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2bwywloT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ej0KXCFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2bwywloT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xAehWXcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NCMzmjU2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jJDa0kuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1B8pYqIG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_BEsfv7QY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lJYHOxT5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lJYHOxT5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bpilYngv, 1, m, &cDelay_bpilYngv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_grHt6QOr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_bpilYngv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bpilYngv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xAehWXcE, 0, m, &cIf_xAehWXcE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lJYHOxT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bpilYngv, 0, m, &cDelay_bpilYngv_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_grHt6QOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bpilYngv, 0, m, &cDelay_bpilYngv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PuA4MjCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dze8Pou7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HHruoi8Z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5FOknQS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_89RUTauR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X7Oo9MKt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_89RUTauR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xAehWXcE, 1, m, &cIf_xAehWXcE_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X7Oo9MKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BEsfv7QY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_dze8Pou7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jJDa0kuY, 1, m, &cIf_jJDa0kuY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HHruoi8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jJDa0kuY, 0, m, &cIf_jJDa0kuY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1B8pYqIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3RVs3ls9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NCMzmjU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3RVs3ls9, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_zPeK60qU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uTkqbkqA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Qo3wmeev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RQk2MCDY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_qCjPNuR4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cqs1kVLb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cqs1kVLb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JoG8HDXi, 1, m, &cDelay_JoG8HDXi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C4pAOKFn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_JoG8HDXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JoG8HDXi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zPeK60qU, 0, m, &cIf_zPeK60qU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cqs1kVLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JoG8HDXi, 0, m, &cDelay_JoG8HDXi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_C4pAOKFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JoG8HDXi, 0, m, &cDelay_JoG8HDXi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PYZgv7EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_refpI5A1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_etEpVKNR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2PTkaIJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dwOx1UZ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ft2WaUY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_dwOx1UZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zPeK60qU, 1, m, &cIf_zPeK60qU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6ft2WaUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qCjPNuR4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_refpI5A1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qo3wmeev, 1, m, &cIf_Qo3wmeev_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_etEpVKNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qo3wmeev, 0, m, &cIf_Qo3wmeev_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RQk2MCDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3MBDth2m, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uTkqbkqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3MBDth2m, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_4YAgU2Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NtF7fceG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_F6gViEac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YHngERJC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ob3WlqeY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LvPOlfc3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LvPOlfc3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f16WWIjU, 1, m, &cDelay_f16WWIjU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R3kAqCs0_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_f16WWIjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f16WWIjU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4YAgU2Lo, 0, m, &cIf_4YAgU2Lo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LvPOlfc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f16WWIjU, 0, m, &cDelay_f16WWIjU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_R3kAqCs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f16WWIjU, 0, m, &cDelay_f16WWIjU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_oCTDrowa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5VhrPyQD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RVrXyjsR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IUZELJUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bs3z7ezj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mrOLGa9x_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_mrOLGa9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ob3WlqeY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_bs3z7ezj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4YAgU2Lo, 1, m, &cIf_4YAgU2Lo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5VhrPyQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F6gViEac, 1, m, &cIf_F6gViEac_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RVrXyjsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F6gViEac, 0, m, &cIf_F6gViEac_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YHngERJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vD2bKnot, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NtF7fceG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vD2bKnot, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_LWrNqdVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_I9zIrgaE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tmZ1B9j5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FUWSIsr5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_co6TwLTS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TfAWPuFt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TfAWPuFt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ruYDjrmD, 1, m, &cDelay_ruYDjrmD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qpAcA22C_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ruYDjrmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ruYDjrmD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LWrNqdVe, 0, m, &cIf_LWrNqdVe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TfAWPuFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ruYDjrmD, 0, m, &cDelay_ruYDjrmD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qpAcA22C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ruYDjrmD, 0, m, &cDelay_ruYDjrmD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FcoMn8tM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hw420WrR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rdamaP13_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HRvlsfli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jmY2SwEu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q95DnK8V_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Q95DnK8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_co6TwLTS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jmY2SwEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LWrNqdVe, 1, m, &cIf_LWrNqdVe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rdamaP13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tmZ1B9j5, 0, m, &cIf_tmZ1B9j5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_hw420WrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tmZ1B9j5, 1, m, &cIf_tmZ1B9j5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FUWSIsr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QSlqOFyM, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_I9zIrgaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QSlqOFyM, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_bOVx7f94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_KiXm9a3T_sendMessage(_c, 0, m);
  cMsg_mxpH3SZk_sendMessage(_c, 0, m);
  cMsg_NYPrzQMb_sendMessage(_c, 0, m);
  cMsg_lI9YQqJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jCvBmojD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_KiXm9a3T_sendMessage(_c, 0, m);
  cMsg_VtSolnr3_sendMessage(_c, 0, m);
  cMsg_bOnd5Lvm_sendMessage(_c, 0, m);
  cMsg_tIIhqc4K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_vvvQcVbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_Yw6SMTFw_sendMessage(_c, 0, m);
  cMsg_VtSolnr3_sendMessage(_c, 0, m);
  cMsg_lI9YQqJX_sendMessage(_c, 0, m);
  cMsg_OQg50L5x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cY1sLx9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_Yw6SMTFw_sendMessage(_c, 0, m);
  cMsg_HUYBjFbf_sendMessage(_c, 0, m);
  cMsg_NYPrzQMb_sendMessage(_c, 0, m);
  cMsg_0MrFiyuz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HwmRhup2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_U3PkDCBx_sendMessage(_c, 0, m);
  cMsg_tIIhqc4K_sendMessage(_c, 0, m);
  cMsg_7psmSk20_sendMessage(_c, 0, m);
  cMsg_NYPrzQMb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_JIjpQhWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_U3PkDCBx_sendMessage(_c, 0, m);
  cMsg_0MrFiyuz_sendMessage(_c, 0, m);
  cMsg_VtSolnr3_sendMessage(_c, 0, m);
  cMsg_9qo5hpYD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tAocfQms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j2CHsiau_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qoubq9Gx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EzqUAkac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j2CHsiau_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qoubq9Gx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AB179jT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e9dAzPPL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iTLGUnDZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yJhZ13fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e9dAzPPL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iTLGUnDZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0eWcNnYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kNzB0FNt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iwEkfBZ8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_O5UKIuJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kNzB0FNt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iwEkfBZ8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KiXm9a3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_tAocfQms_sendMessage(_c, 0, m);
  cMsg_yJhZ13fb_sendMessage(_c, 0, m);
  cMsg_O5UKIuJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Yw6SMTFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_EzqUAkac_sendMessage(_c, 0, m);
  cMsg_AB179jT1_sendMessage(_c, 0, m);
  cMsg_O5UKIuJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_U3PkDCBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_EzqUAkac_sendMessage(_c, 0, m);
  cMsg_yJhZ13fb_sendMessage(_c, 0, m);
  cMsg_0eWcNnYH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_cORzIvWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ijAK8Iv7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aXzuuscj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_la5qQjOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ijAK8Iv7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aXzuuscj_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ftZBFJM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3Uffnn3g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KC39lpMJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RepAqeLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3Uffnn3g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KC39lpMJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rFRGIiIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CyJajx3Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Fqq4gP8I_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x13K95f0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CyJajx3Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Fqq4gP8I_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VtSolnr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_la5qQjOb_sendMessage(_c, 0, m);
  cMsg_RepAqeLk_sendMessage(_c, 0, m);
  cMsg_x13K95f0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_mxpH3SZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_la5qQjOb_sendMessage(_c, 0, m);
  cMsg_ftZBFJM7_sendMessage(_c, 0, m);
  cMsg_rFRGIiIm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HUYBjFbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_cORzIvWT_sendMessage(_c, 0, m);
  cMsg_RepAqeLk_sendMessage(_c, 0, m);
  cMsg_rFRGIiIm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_2MpflSSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2PTkaIJO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PYZgv7EF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_me5i6glI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2PTkaIJO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PYZgv7EF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yepsO9Rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IUZELJUe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oCTDrowa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5zai2JdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IUZELJUe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oCTDrowa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Pr5vu9VN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HRvlsfli_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FcoMn8tM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7rvJui82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_HRvlsfli_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FcoMn8tM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0MrFiyuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_2MpflSSb_sendMessage(_c, 0, m);
  cMsg_5zai2JdC_sendMessage(_c, 0, m);
  cMsg_7rvJui82_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_tIIhqc4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_me5i6glI_sendMessage(_c, 0, m);
  cMsg_yepsO9Rx_sendMessage(_c, 0, m);
  cMsg_7rvJui82_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_lI9YQqJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_me5i6glI_sendMessage(_c, 0, m);
  cMsg_5zai2JdC_sendMessage(_c, 0, m);
  cMsg_Pr5vu9VN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_STghPm4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YFrSb46i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dLuLYpJJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RduAg9b5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YFrSb46i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_dLuLYpJJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OXg1SPgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EtuSoTKW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FkG8KS3b_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_y3GDxshh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EtuSoTKW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FkG8KS3b_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Xj3LrocV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5FOknQS9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PuA4MjCA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Yw2Bh0rA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5FOknQS9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PuA4MjCA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NYPrzQMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_RduAg9b5_sendMessage(_c, 0, m);
  cMsg_y3GDxshh_sendMessage(_c, 0, m);
  cMsg_Yw2Bh0rA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_bOnd5Lvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_RduAg9b5_sendMessage(_c, 0, m);
  cMsg_OXg1SPgy_sendMessage(_c, 0, m);
  cMsg_Xj3LrocV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9qo5hpYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_STghPm4g_sendMessage(_c, 0, m);
  cMsg_OXg1SPgy_sendMessage(_c, 0, m);
  cMsg_Yw2Bh0rA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7psmSk20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_cORzIvWT_sendMessage(_c, 0, m);
  cMsg_ftZBFJM7_sendMessage(_c, 0, m);
  cMsg_x13K95f0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_OQg50L5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_STghPm4g_sendMessage(_c, 0, m);
  cMsg_y3GDxshh_sendMessage(_c, 0, m);
  cMsg_Xj3LrocV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_ebLxwvmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GjhLvFTH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_7JJU3VNW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nAW923HN, 0, m, &cSlice_nAW923HN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_J8EaFbN8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_nAW923HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8JWWpMBY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8JWWpMBY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_36fuV4Om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8JWWpMBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_8JWWpMBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0RAhRzT7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Z1E92uHs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E7XtQ40z, 0, m, &cSlice_E7XtQ40z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oGnXqt6A_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_E7XtQ40z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yUnSsEQ0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yUnSsEQ0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_7tFZj2P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yUnSsEQ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_yUnSsEQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mDMgPr9k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_oGnXqt6A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KfGzKUTp, 0, m, &cSlice_KfGzKUTp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7JJU3VNW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_KfGzKUTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_S87hD237_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_S87hD237_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_fK5qLVgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S87hD237_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_S87hD237_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UPOJ9q4U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_J8EaFbN8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UMuwtWbk, 0, m, &cSlice_UMuwtWbk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nK2ViHQh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_UMuwtWbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T1WxeqEm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T1WxeqEm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_jTI13zg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T1WxeqEm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_T1WxeqEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nhAve4l7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_nK2ViHQh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LuxUNe4s, 0, m, &cSlice_LuxUNe4s_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ugO1GvOa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_LuxUNe4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sVEyTBpD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sVEyTBpD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_ypWNznak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sVEyTBpD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_sVEyTBpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DxuiZN6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_4cp6d2xQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_O2zpsHH8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_O2zpsHH8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Af4LvOvB, 1, m, &cDelay_Af4LvOvB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EbUIlVNB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Af4LvOvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Af4LvOvB, m);
  cMsg_k9R1ZGZC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_O2zpsHH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Af4LvOvB, 0, m, &cDelay_Af4LvOvB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EbUIlVNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Af4LvOvB, 0, m, &cDelay_Af4LvOvB_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_cuYSi4L2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GXHWqtF9, HV_BINOP_SUBTRACT, 0, m, &cBinop_GXHWqtF9_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_WeKyVdLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nNxkUB81_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ws6vrIoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nNxkUB81_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_y0FrAwLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cuYSi4L2, 0, m, &cVar_cuYSi4L2_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_lx1xHzs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cc67jJBN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XxFwVh8J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L4VPKOam_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GXHWqtF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6wsuyeYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6wsuyeYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HHYiRvye_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_HHYiRvye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ktBLRAWf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vS9j5SBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NBOoysTn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3iBP1X2E_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3iBP1X2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tFRcV3Db_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_NBOoysTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WeKyVdLY, 1, m, &cIf_WeKyVdLY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6CGy2ryo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ws6vrIoN, 1, m, &cIf_ws6vrIoN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_tFRcV3Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WeKyVdLY, 0, m, &cIf_WeKyVdLY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ktBLRAWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ws6vrIoN, 0, m, &cIf_ws6vrIoN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_XxFwVh8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GXHWqtF9, HV_BINOP_SUBTRACT, 1, m, &cBinop_GXHWqtF9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Cc67jJBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_L4VPKOam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cuYSi4L2, 0, m, &cVar_cuYSi4L2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nNxkUB81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mUR0Vm0R, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ugO1GvOa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l2I7kbWe, 0, m, &cSlice_l2I7kbWe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_l2I7kbWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yClKC1Vq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yClKC1Vq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_nJWH7MIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yClKC1Vq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_yClKC1Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3mnP7EhX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_UlAmMIHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SHZPc12Y, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_uz2J8gpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4F7gYPA3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_ZlfKcOcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cIZo57ZY, 0, m, &cVar_cIZo57ZY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GjhLvFTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cMfjKoHD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Eb7ztOYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oFG8Xktz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_6XS2Q23L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4cp6d2xQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_k9R1ZGZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OS8UkrNa, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_oFG8Xktz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OS8UkrNa, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_y2Of9MJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_RsoGDh9c_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RsoGDh9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D85wjjog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_D85wjjog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U7UvyZeY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_npRP6ez2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n5IeEk2B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7cbMbEdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7fO3WMiW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ht7kIrJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c38bwa69, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_CdWAYdsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F1P9phkF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_4HC8ZGJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UpyXTIjK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z1E92uHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_3XLaRrcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UpyXTIjK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z1E92uHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_EeJwixdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BRLqlJoi, 0, m, &cVar_BRLqlJoi_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5tb4MAb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UpyXTIjK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z1E92uHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Wcl3zw5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UpyXTIjK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z1E92uHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_g16S0ohF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UpyXTIjK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z1E92uHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rpWnEasn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rTp0L0WR, 0, m, &cVar_rTp0L0WR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9w7NNbBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RCnhPT70, 0, m, &cVar_RCnhPT70_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IvXZvdQl, 0, m, &cVar_IvXZvdQl_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZFkSvyvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_EeJwixdy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5Gn4VnYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zEMvhRCB, 0, m, &cVar_zEMvhRCB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_n5IeEk2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_UpyXTIjK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z1E92uHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_r9uYT2d7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_npRP6ez2, 0, m, &cVar_npRP6ez2_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_F1P9phkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_euJTJVVv_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_fUNexbCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UVBPyGxL, 0, m, &cVar_UVBPyGxL_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_uHsdGA6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_EeJwixdy_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Vl0u6dsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rTp0L0WR, 0, m, &cVar_rTp0L0WR_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_8LN2Q7Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bzQWDuoa, 0, m, &cVar_bzQWDuoa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BCxrgBxM, 0, m, &cVar_BCxrgBxM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RThUq8Nk, 0, m, &cVar_RThUq8Nk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BQmecZmK, 0, m, &cVar_BQmecZmK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RDU0FLiT, 0, m, &cVar_RDU0FLiT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ziqLsgJK, 0, m, &cVar_ziqLsgJK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_36fuV4Om, 0, m, &cVar_36fuV4Om_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7tFZj2P0, 0, m, &cVar_7tFZj2P0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fK5qLVgi, 0, m, &cVar_fK5qLVgi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jTI13zg5, 0, m, &cVar_jTI13zg5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ypWNznak, 0, m, &cVar_ypWNznak_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nJWH7MIQ, 0, m, &cVar_nJWH7MIQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qH9uqMoG_sendMessage);
  cMsg_5Gn4VnYF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_kRO2Njba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zEMvhRCB, 0, m, &cVar_zEMvhRCB_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_HAKUnE9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RCnhPT70, 0, m, &cVar_RCnhPT70_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_lqrEN6ys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IvXZvdQl, 0, m, &cVar_IvXZvdQl_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_rxwMRWKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kfSdvrn1, 0, m, &cVar_kfSdvrn1_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_digrYlp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pJsJUQWr, 0, m, &cVar_pJsJUQWr_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_RMw8wVGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_aRtG8Dl7_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ZGYlasyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2a29g6EB_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3O7DtM8L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JZqxHGrj_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_jI8hNGWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XGqQNHEG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FpW3GSS0_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_WmcLpa1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yu7omDfM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_0RAhRzT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_htFxCeXQ, 0, m, &cVar_htFxCeXQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_nhAve4l7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ebLxwvmZ, 0, m, &cVar_ebLxwvmZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_UPOJ9q4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ZlfKcOcn_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_mDMgPr9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Tm2HeCcD_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eb7ztOYL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6XS2Q23L_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_DxuiZN6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vS9j5SBW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6CGy2ryo_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_3mnP7EhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y2Of9MJh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_R1NMWyCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_npRP6ez2, 0, m, &cVar_npRP6ez2_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_GwwZ7LuK, VIf(I0));
    __hv_varread_f(&sVarf_bhkLpuRW, VOf(Bf0));
    __hv_varread_f(&sVarf_aoSlpGHU, VOf(Bf1));
    __hv_varread_f(&sVarf_kzqw34n2, VOf(Bf2));
    __hv_varread_f(&sVarf_o5rS2NPL, VOf(Bf3));
    __hv_varread_f(&sVarf_7o7dY1Sm, VOf(Bf4));
    __hv_varread_f(&sVarf_qXFuouMu, VOf(Bf5));
    __hv_varread_f(&sVarf_OrjZoUSF, VOf(Bf6));
    __hv_varwrite_f(&sVarf_lPoQXBQa, VIf(I0));
    __hv_varread_f(&sVarf_mNaJUbQ7, VOf(Bf7));
    __hv_line_f(&sLine_7CYmPH9c, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_kodaExi1, VOf(Bf9));
    __hv_line_f(&sLine_M2mowKDl, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_gtScweVq, VOf(Bf8));
    __hv_line_f(&sLine_sJDeZ1Q2, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_o5rS2NPL, VIf(Bf11));
    __hv_varread_f(&sVarf_lPoQXBQa, VOf(Bf11));
    __hv_line_f(&sLine_kq6ik9OS, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_CNDCVGgq, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_7bwdEL1e, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_7o7dY1Sm, VIf(Bf10));
    __hv_line_f(&sLine_EUlYdPIc, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_CDuDlFF0, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_KDwaeqBR, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_qXFuouMu, VIf(Bf10));
    __hv_line_f(&sLine_sJEMvvnq, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_CMIZNGbb, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_nQU5ytFk, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_OrjZoUSF, VIf(Bf10));
    __hv_varwrite_f(&sVarf_mNaJUbQ7, VIf(Bf0));
    __hv_varwrite_f(&sVarf_kodaExi1, VIf(Bf1));
    __hv_varwrite_f(&sVarf_gtScweVq, VIf(Bf2));
    sEnv_process(this, &sEnv_XDUJyCnX, VIf(Bf3), &sEnv_XDUJyCnX_sendMessage);
    sEnv_process(this, &sEnv_5p9xpoVC, VIf(I0), &sEnv_5p9xpoVC_sendMessage);
    __hv_line_f(&sLine_GfEjBxHa, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_wzfMWryP, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_uMU7KxTM, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_2wYReOrm, VOf(Bf3));
    __hv_line_f(&sLine_7WpoyCPh, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_bhkLpuRW, VIf(Bf0));
    __hv_varwrite_f(&sVarf_2wYReOrm, VIf(Bf4));
    __hv_varwrite_f(&sVarf_mWOivtLS, VIf(Bf5));
    __hv_varwrite_f(&sVarf_VoSWOqyN, VIf(Bf6));
    __hv_varread_f(&sVarf_VoSWOqyN, VOf(Bf6));
    __hv_line_f(&sLine_DmIfd1F8, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_kzqw34n2, VIf(Bf4));
    __hv_varread_f(&sVarf_mWOivtLS, VOf(Bf4));
    __hv_line_f(&sLine_BhKLHbmO, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_aoSlpGHU, VIf(Bf4));
    __hv_varwrite_f(&sVarf_EYrpPKDd, VIf(Bf2));
    __hv_varwrite_f(&sVarf_VgMgMVPr, VIf(I1));
    __hv_varread_f(&sVarf_ANNDVnpM, VOf(Bf2));
    __hv_varread_f(&sVarf_B3S3LxMo, VOf(Bf4));
    __hv_varread_f(&sVarf_VrhPnmDA, VOf(Bf0));
    __hv_varread_f(&sVarf_2pZM0lap, VOf(Bf5));
    __hv_varread_f(&sVarf_eWZA6NGG, VOf(Bf3));
    __hv_varread_f(&sVarf_N26gu8By, VOf(Bf6));
    __hv_varread_f(&sVarf_ebw4Youd, VOf(Bf1));
    __hv_varwrite_f(&sVarf_96IIsRF2, VIf(I1));
    __hv_varread_f(&sVarf_k4avkW2M, VOf(Bf10));
    __hv_line_f(&sLine_3MBDth2m, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_dOTuhx4s, VOf(Bf7));
    __hv_line_f(&sLine_vD2bKnot, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_naEhckQT, VOf(Bf11));
    __hv_line_f(&sLine_QSlqOFyM, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_2pZM0lap, VIf(Bf12));
    __hv_varread_f(&sVarf_96IIsRF2, VOf(Bf12));
    __hv_line_f(&sLine_eN3lT8Js, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_QjvQ1T2b, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_q6TdOjHJ, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_eWZA6NGG, VIf(Bf9));
    __hv_line_f(&sLine_ovr54S2d, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_iyFFNs4D, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_2bwywloT, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_N26gu8By, VIf(Bf9));
    __hv_line_f(&sLine_Rx6jOTAq, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_ceF7bNRq, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_3RVs3ls9, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_ebw4Youd, VIf(Bf9));
    __hv_varwrite_f(&sVarf_k4avkW2M, VIf(Bf2));
    __hv_varwrite_f(&sVarf_dOTuhx4s, VIf(Bf4));
    __hv_varwrite_f(&sVarf_naEhckQT, VIf(Bf0));
    sEnv_process(this, &sEnv_y0FrAwLx, VIf(Bf5), &sEnv_y0FrAwLx_sendMessage);
    sEnv_process(this, &sEnv_lx1xHzs9, VIf(I1), &sEnv_lx1xHzs9_sendMessage);
    __hv_line_f(&sLine_mUR0Vm0R, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_OS8UkrNa, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_U7UvyZeY, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_qMdzBEgv, VOf(Bf5));
    __hv_line_f(&sLine_4F7gYPA3, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_ANNDVnpM, VIf(Bf2));
    __hv_varwrite_f(&sVarf_qMdzBEgv, VIf(Bf3));
    __hv_varwrite_f(&sVarf_uBv8125w, VIf(Bf6));
    __hv_varwrite_f(&sVarf_AHqxtVqH, VIf(Bf1));
    __hv_varread_f(&sVarf_AHqxtVqH, VOf(Bf1));
    __hv_line_f(&sLine_cMfjKoHD, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_VrhPnmDA, VIf(Bf3));
    __hv_varread_f(&sVarf_uBv8125w, VOf(Bf3));
    __hv_line_f(&sLine_SHZPc12Y, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_B3S3LxMo, VIf(Bf3));
    __hv_varwrite_f(&sVarf_F2V8D8kC, VIf(Bf0));
    __hv_varread_f(&sVarf_GwwZ7LuK, VOf(Bf0));
    __hv_line_f(&sLine_c38bwa69, VOf(Bf3));
    __hv_varread_f(&sVarf_EYrpPKDd, VOf(Bf2));
    __hv_line_f(&sLine_7fO3WMiW, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_VgMgMVPr, VOf(Bf2));
    __hv_varread_f(&sVarf_F2V8D8kC, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
